@@ -516,6 +516,12 @@ pref("javascript.options.showInConsole",          true);
 pref("general.warnOnAboutConfig",                 false);
 #endif
 
+// Enable unlinking of ghost windows so they can be garbage collected.
+pref("browser.ghostbuster.enabled",               true);
+// Disable GC on memory pressure, avoid incessant recycling when websites
+// misbehave. Should also avoid spurious GCs during ghostbusting.
+pref("javascript.options.gc_on_memory_pressure",  false);
+
 // This is the pref to control the location bar, change this to true to 
 // force this - this makes the origin of popup windows more obvious to avoid
 // spoofing. We would rather not do it by default because it affects UE for web
