@@ -285,6 +285,8 @@ BlacklistOSToOperatingSystem(const nsAString& os)
     return OperatingSystem::OSX12_0;
   else if (os.EqualsLiteral("Darwin 22"))
     return OperatingSystem::OSX13_0;
+  else if (os.EqualsLiteral("Darwin 23"))
+    return OperatingSystem::OSX14_0;
   // For historical reasons, "All" in blocklist means "All Windows"
   else if (os.EqualsLiteral("All"))
     return OperatingSystem::Windows;
@@ -984,7 +986,7 @@ GfxInfoBase::EvaluateDownloadedBlacklist(nsTArray<GfxDriverInfo>& aDriverInfo)
           } else {
             RemovePrefForDriverVersion();
           }
-          MOZ_FALLTHROUGH;
+          [[fallthrough]];
 
         case nsIGfxInfo::FEATURE_BLOCKED_MISMATCHED_VERSION:
         case nsIGfxInfo::FEATURE_BLOCKED_DEVICE:
