@@ -145,12 +145,14 @@ nsPrintDialogServiceX::Show(nsPIDOMWindowOuter *aParent, nsIPrintSettings *aSett
       [dict setObject: [NSNumber numberWithFloat: 1]
                forKey: NSPrintScalingFactor];
     }
+#if defined(MAC_OS_X_VERSION_10_6) && MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_6
     // Set the scaling factor to 100% in the NSPrintInfo
     // object so that it will not affect the paper size
     // retrieved from the PMPageFormat routines.
     [copy setScalingFactor:1.0];
   } else {
     aSettings->SetScaling([copy scalingFactor]);
+#endif
   }
 
   // Set the adjusted paper size now that we've updated
